@@ -25,6 +25,7 @@
 #include <unistd.h>
 #include <time.h>
 #include <errno.h>
+#include <assert.h>
 
 using namespace std;
 
@@ -35,7 +36,7 @@ T getrandnum(T max)
   T rval;
   if (urandev) {
     /* /dev/urandom works. */
-    urandev.read((void*)&rval, sizeof(rval));
+    urandev.read((char*)&rval, sizeof(rval));
   } else {
 /* this ifdef is messy but does the right thing - we only try /dev/random
  * if it is defined. */
@@ -280,11 +281,14 @@ int main(int argc, char *argv[])
     printfileerror(locdataidx);
   if (readfile(street, streetidx.c_str()) == 0)
     printfileerror(streetidx);
-  if (readfile(firstname, mnamesidx.c_str()) == 0) {
+  if (male) {
+      if (readfile(firstname, mnamesidx.c_str()) == 0)
+          printfileerror(streetidx);
+  }
+  if (female) {
     if (readfile(firstname, fnamesidx.c_str()) == 0)
-      printfileerror(mnamesidx + "and" + fnamesidx);
-  } else
-      readfile(firstname, fnamesidx.c_str());
+      printfileerror(fnamesidx);
+  }
   if (readfile(lastname, lnamesidx.c_str()) == 0)
     printfileerror(lnamesidx);
   
